# code formatting
This page describes how to set up a pre-commit hook that checks code formatting.

# Disclaimer

No warranty is given that the presented pre-commit hook works as expected and that it does not destroy anything. Use at your own risk!

# Operating system

This should work on Linux.

# Prerequisites

* `git-clang-format` installed somewhere in the `$PATH`. `git-clang-format` might be shipped with `clang` in your distro and is also available from [here](https://llvm.org/svn/llvm-project/cfe/trunk/tools/clang-format/git-clang-format).

# Setup

* Save the script `pre-commit` as `.git/hooks/pre-commit` and make it executable
* In order to use format shipped with OGS, you have to execute the following command, which sets up the right settings: `git config --local clangFormat.style file`.
* Now whenever you commit something, its formatting will get checked and the commit is aborted if the formatting does now comply.

# Error message generated by the pre-commit hook

In case reformatting of your code is needed, the pre-commit hook will print the following error message and the commit will be aborted:
```
$ git commit
The code you want to commit needs to be reformatted.
Run the following, then commit:
  git add NumLib/Extrapolation/ExtrapolatableElementCollection.h NumLib/Extrapolation/LocalLinearLeastSquaresExtrapolator.cpp && \
  git clang-format NumLib/Extrapolation/ExtrapolatableElementCollection.h NumLib/Extrapolation/LocalLinearLeastSquaresExtrapolator.cpp
```

In most cases the last two lines of the error message can be readily copied to your terminal and executed right away. They will fix the code formatting (Note: They won't stage—i.e., `git add`–the changes `clang-format` makes). Afterwards you can commit.

# References

This is based on the pre-commit hook shipped with git and on https://dx13.co.uk/articles/2015/4/3/Setting-up-git-clang-format.html (retrieved 2017-07-24).
